class Particle {
  constructor(x, y) {
    this.x = x;
    this.y = y;
    this.size = Math.random() * 3 + 1;
    this.speedX = Math.random() * 3 - 1.5;
    this.speedY = Math.random() * 3 - 1.5;
    this.color = `hsla(${Math.random() * 60 + 180}, 70%, 50%, 0.8)`;
  }

  update() {
    this.x += this.speedX;
    this.y += this.speedY;

    if (this.size > 0.2) this.size -= 0.1;
  }

  draw(ctx) {
    ctx.fillStyle = this.color;
    ctx.beginPath();
    ctx.arc(this.x, this.y, this.size, 0, Math.PI * 2);
    ctx.fill();
  }
}

class CellSimulation {
  constructor() {
    this.canvas = document.getElementById('cellCanvas');
    this.ctx = this.canvas.getContext('2d');
    this.particles = [];
    this.resize();
    this.init();

    window.addEventListener('resize', () => this.resize());
    this.animate();
  }

  resize() {
    this.canvas.width = this.canvas.offsetWidth;
    this.canvas.height = this.canvas.offsetHeight;
  }

  init() {
    for (let i = 0; i < 100; i++) {
      this.particles.push(
        new Particle(
          Math.random() * this.canvas.width,
          Math.random() * this.canvas.height
        )
      );
    }
  }

  animate() {
    this.ctx.fillStyle = 'rgba(0, 5, 17, 0.1)';
    this.ctx.fillRect(0, 0, this.canvas.width, this.canvas.height);

    this.particles.forEach((particle, index) => {
      particle.update();
      particle.draw(this.ctx);

      if (particle.size <= 0.2) {
        this.particles.splice(index, 1);
        this.particles.push(
          new Particle(
            Math.random() * this.canvas.width,
            Math.random() * this.canvas.height
          )
        );
      }
    });

    requestAnimationFrame(() => this.animate());
  }
}

document.addEventListener('DOMContentLoaded', () => {
  new CellSimulation();
});